# localhook

<p align="center"> Webhooks delivered on terminal <p>
<p align="center">
<a href="https://pypi.org/project/localhook/" target="_blank">
    <img src="https://img.shields.io/pypi/v/localhook?color=%2334D058&label=pypi%20package" alt="Package version">
</a>
</p>

## Installation

<div class="termy">

```console
$ pip install localhook

---> 100%
```
</div>

## Run it

Run the server with:

<div class="termy">

```console
$ localhook --port 9090

         Webhooks Delivered Locally   

🎉 Ready to receive webhooks on terminal 👍
🎉 Set your webhook URL as http://50c3f3e44dca.ngrok.io
🎉 Traffic stats available on http://127.0.0.1:4040

```
Now set the URL to receive the webhooks in terminal
</div>
